import * as service from '../scss/admin.scss';
import CustomerBookings from './components/customer-bookings.mjs';
import SettingsFormCustomizer from './components/settings-form-customizer.mjs';
import HtmlExtensionRegistry from './html/html-extension-registry.mjs';
import SettingsShortcodeGenerator from "./components/settings-shortcode-generator.mjs";
import eventsForm from "./components/events-form.mjs";
import SubscriptionPage from "./components/subscription-page.mjs";
import StringHelper from "./services/string-helper.mjs";

(function (_w, _d) {
    let urlParams = new URLSearchParams(window.location.search);
    let actions = {
        'wpcb_settings.php': eventsForm,
        'cb_shortcode_generator.php': shortCodeGenerator,
        'customer_bookings.php': customerBookingsPage,
        'wpcb_form_customize_settings.php': SettingsFormCustomizerPage,
        'wpcb_subscription_settings.php': SubscriptionPage,
    };

    let action = actions[urlParams.get('page')];
    if (action) {
        action();
    }

    _w.addEventListener('keydown', function (evt) {

        let combinations = [
            // combination of alt + d and for mac cmd + d
            evt.key === 'd' && (evt.altKey === true || evt.metaKey === true),

            // combination of alt + h and for mac cmd + h
            evt.key === 'h' && (evt.altKey === true || evt.metaKey === true),
        ]

        console.log(combinations);
        //any combination of key press
        if (combinations.includes(true)) {
            console.log('key pressed');
            evt.preventDefault();
            //reload window adding an extra parameter to the url
            _w.location.href = _w.location.href + '&debug_mode'
            return false;
        }
    });

    _w.addEventListener('click', function (evt) {
        if (evt.target.id.indexOf('delete-wpcb-caches') > -1) {
            evt.preventDefault();

            let answer = prompt('Are you sure you want to delete all caches? Type "yes" to confirm.', 'no');
            if (answer === 'yes') {
                DeleteTransients().then((data) => {
                    _d.querySelector('.jims-d-menu-toolbar .notifications').innerHTML = `caches deleted`;
                });
            }
            return false;
        }

        if (evt.target.id.indexOf('update-leads-record') > -1) {
            evt.preventDefault();

            UpdateLeadsRecord().then((data) => {
                _d.querySelector('.jims-d-menu-toolbar .notifications').innerHTML = `Leads Updated`;
            });

            return false;
        }
    });

    function customerBookingsPage() {
        const customerBookingsData = new CustomerBookings();

        if (window.graphData !== undefined) {
            customerBookingsData.barChart('booking-overview', graphData.success, graphData.failed);
        }
    }

    function SettingsFormCustomizerPage() {
        const customizer = _d.querySelector('#jims-form-customizer');

        if (window.jims_wpcb_variables === undefined || customizer === null) {
            throw new Error('jims_wpcb_variables.home_url is undefined');
        }

        const settingsFormCustomizer = new SettingsFormCustomizer(customizer, jims_wpcb_variables);
        settingsFormCustomizer.init();
    }


    function shortCodeGenerator() {
        const element = _d.querySelector('.jims-wpcb-shortcode-generator');

        if (element !== null) {
            window.shortcodeGenerator = new SettingsShortcodeGenerator(element, jims_wpcb_variables);
            window.shortcodeGenerator.init();
        }
    }


    function populatedOptionField(target, listObject, ValueName, LabelName, placeholder) {
        let template = '<option value="{{val}}">{{label}}</option>';
        let html = [];
        html.push(`<option value="" selected>${placeholder}</option>`);

        listObject.forEach(element => {
            html.push(template.replace('{{val}}', element[ValueName]).replace('{{label}}', element[LabelName]));
        });

        target.innerHTML = html.join('');
    }

    function formatMessage(formData) {
        const StringHelper = new StringHelper();
        return StringHelper.formatMessage(formData);
    }

    async function DeleteTransients() {
        /**
         * method post, path: /jims-wpcb/v1/options/clear-transients
         */
        const rawResponse = await fetch(`${jims_wpcb_variables.home_url}/wp-json/jims-wpcb/v1/options/clear-transients`, {
            method: 'POST',
            headers: {
                'Accept': 'application/json',
                'Content-Type': 'application/json'
            }
        });
        const content = await rawResponse.json();
        console.log(content);

        return rawResponse;
    }

    async function UpdateLeadsRecord() {
        const rawResponse = await fetch(`${jims_wpcb_variables.home_url}/wp-json/jims-wpcb/v1/options/leads`, {
            method: 'POST',
            headers: {
                'Accept': 'application/json',
                'Content-Type': 'application/json'
            }
        });
        const content = await rawResponse.json();
        console.log(content);

        return rawResponse;
    }
}(window, document));