import jimsServices from '../services/jims-services.mjs';
import StringHelper from "../services/string-helper.mjs";

function eventsForm() {
    const JmsServices = new jimsServices(
        window.jims_wpcb_variables.rest_url,
        jims_wpcb_variables.bookingFormDivisionId,
        window.jims_wpcb_variables.country
    );
    const Str = new StringHelper();


    const endpoint = `${jims_wpcb_variables.home_url}/wp-json/jims-wpcb/v1/options/form-events`;
    const adminEndpoint = `${jims_wpcb_variables.home_url}/wp-json/jims-wpcb/v1/options/form-events-admin`;
    const _d = document;

    const form = _d.querySelector('#jims-events-form');
    const divisionSelect = form.querySelector('#divisions');
    const divisionId = _d.querySelector('#divisions').value;

    //disable the division select
    form.classList.add('loading');
    _d.querySelector('.page-is-loading').style.opacity = 1;

    //Load the division list
    JmsServices.getDivisionList().then((data) => {
        let divisions = data;

        let template = `<option value="{{id}}" {{isSelected}}>{{name}}</option>`;
        let html = '';
        divisions.forEach((division) => {
            let selected = parseInt(division.id) === parseInt(window.jims_wpcb_variables.bookingFormDivisionId) ? 'selected' : '';
            let option = template
                .replace('{{id}}', division.id)
                .replace('{{name}}', division.name)
                .replace('{{isSelected}}', selected);
            html += option;
        });

        divisionSelect.innerHTML = html;
    }).finally(() => {
        form.classList.remove('loading');
        _d.querySelector('.page-is-loading').style.opacity = 0;
    });

    JmsServices.getCountries().then((data) => {
        let countries = data;

        let template = `<option value="{{code}}" {{selected}}>{{name}}</option>`;
        let html = '';
        countries.forEach((country) => {
            let selected = country.symbol === window.jims_wpcb_variables.country ? 'selected' : '';
            let option = template
                .replace('{{code}}', country.symbol)
                .replace('{{name}}', country.name)
                .replace('{{selected}}', selected);
            html += option;
        });

        form.querySelector('#country').innerHTML = html;
    });


    console.log('running events form');
    form.querySelectorAll('input[type=password]').forEach((input) => {
        //add html next to the input
        let showPassWordButton = _d.createElement('button');
        showPassWordButton.innerHTML = 'Show Hidden Content';
        showPassWordButton.type = 'button';
        showPassWordButton.classList.add('show-password');
        showPassWordButton.addEventListener('click', (evt) => {
            evt.preventDefault();
            if (input.type === 'password') {
                input.type = 'text';
                showPassWordButton.innerHTML = 'Hide Content';
            } else {
                input.type = 'password';
                showPassWordButton.innerHTML = 'Show Hidden Content';
            }
        });

        input.parentNode.appendChild(showPassWordButton);
    });

    form.querySelector('.setting-group.email-settings:not(.hidden) #notification-scheduler')?.addEventListener('change', (evt) => {
        //value 0 should be system so we show the div.scheduler-data.scheduler-command
        //value 1 should be cron so we show the div.scheduler-data.smtp-data
        let value = evt.target.value;
        if (value === '0') {
            form.querySelector('.scheduler-data.scheduler-command').classList.remove('hidden');
            form.querySelector('.scheduler-data.smtp-data').classList.add('hidden');
        } else {
            form.querySelector('.scheduler-data.scheduler-command').classList.add('hidden');
            form.querySelector('.scheduler-data.smtp-data').classList.remove('hidden');
        }
    });

    form.addEventListener('submit', (evt) => {
        evt.preventDefault();
        let formdata = new FormData(evt.target);
        console.log(formdata);
        evt.target.querySelector('input[type=submit]').classList.add('disabled');

        // if (_d.querySelector('#divisions').value !== divisionId) {
        //     fetch(`${jims_wpcb_variables.home_url}/wp-json/jims-wpcb/v1/customize/delete-all-options`, {
        //         method: 'POST',
        //         headers: {
        //             'Accept': 'application/json',
        //             'Content-Type': 'application/json'
        //         }
        //     })
        //         .then(response => response.json())
        //         .then(data => {
        //             console.log(data);
        //         });
        // }

        SaveData(Str.formatMessage(formdata), evt.target);

        return false;
    });


    form.querySelector('#delete-form').addEventListener('click', (evt) => {
        evt.preventDefault();
        _d.querySelector('#delete-form').classList.add('disabled');
        DeleteOptions().then(() => {
            form.reset();
        });

        return false;
    });

    // form.querySelector('#clear-form').addEventListener('click', (evt) => {
    //     form.reset();
    // });

    async function DeleteOptions() {
        if (typeof wpcbSecret == 'undefined') return;

        const rawResponse = await fetch(adminEndpoint, {
            method: 'POST',
            headers: {
                'Accept': 'application/json',
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({'allow': wpcbSecret})
        });
        const content = await rawResponse.json();
        _d.querySelector('#delete-form').classList.remove('disabled');

        return rawResponse;
    }

    async function SaveData(data, formElement) {
        const rawResponse = await fetch(endpoint, {
            method: 'POST',
            headers: {
                'Accept': 'application/json',
                'Content-Type': 'application/json'
            },
            body: JSON.stringify(data)
        });
        const content = await rawResponse.json();
        formElement.querySelector('input[type=submit]').classList.remove('disabled');
        console.log(content);
    }
}


export default eventsForm;