<?php
/**
 *
 */

namespace JimsCustomerBooking\Helpers;


use  Defuse\Crypto\Crypto;
use Defuse\Crypto\Exception\BadFormatException;
use Defuse\Crypto\Exception\WrongKeyOrModifiedCiphertextException;
use Defuse\Crypto\Key;
use Defuse\Crypto\Exception\EnvironmentIsBrokenException;


/**
 * Class HashHelper
 * This class is intended to serve as adapter in case we need
 * to change the hashing algorithm or library
 *
 * @package JimsCustomerBooking\Helpers
 */
class HashHelper
{
    /**
     * @throws EnvironmentIsBrokenException
     * @throws BadFormatException
     */
    public static function create($string, $salt = '', $prefix = 'lead_'): string
    {
        return $prefix . Crypto::encrypt($string, self::getKey($salt));
    }

    public static function isHash($string, $prefix = 'lead_'): bool
    {
        //if the string starts the prefix
        return str_starts_with($string, $prefix);
    }

    /**
     * @throws WrongKeyOrModifiedCiphertextException
     * @throws EnvironmentIsBrokenException
     * @throws BadFormatException
     */
    public static function deHash($string, $salt = '', $prefix = 'lead_'): string
    {
        $hash = str_replace($prefix, '', $string);

        //decode the string
        return Crypto::decrypt($hash, self::getKey($salt));

    }


    /**
     * @throws EnvironmentIsBrokenException
     * @throws BadFormatException
     */
    public static function getKey($salt): Key
    {
        return Key::loadFromAsciiSafeString($salt);
    }

    /**
     * Write a check if the key is valid, the key should be 136 characters long and have only alphanumeric characters
     */
    public static function isValidKey($key): bool
    {
        return strlen($key) === 136 && ctype_alnum($key);
    }

}