<?php

namespace JimsCustomerBooking\Integrations;

/**
 * This class is the base class for all notifications
 */
abstract class ANotification
{

    const NOTIFICATION_SERVICE_EMAIL = 'email';

    const NOTIFICATION_SERVICE_DIRECT = 'direct';

    const NOTIFICATION_TYPE_NOTIFICATION = 'notification';

    const NOTIFICATION_TYPE_ERROR = 'error';

    const NOTIFICATION_TYPE_INFO = 'success';


    /**
     * @var bool
     */
    protected $test_mode = false;

    /**
     * @var string
     */
    protected string $apiKey = '';

    /**
     * @var string
     */
    protected string $service = '';


    /**
     * @var mixed
     */
    protected mixed $service_provider = null;

    /**
     * @var string
     */
    protected array $messages = [];


    /**
     *
     * @var array
     */
    protected array $service_response = [];


    /**
     * @return string|array
     */
    public function getMessage($type): string|array
    {
        return $this->messages[$type] ?? '';
    }

    /**
     * @param string $message
     */
    public function setMessage(string|array $message, $type = self::NOTIFICATION_TYPE_NOTIFICATION): void
    {
        $this->message[$type] = $message;
    }


    /**
     * @param $vars
     * @return bool
     */
    abstract function send(string $type = self::NOTIFICATION_TYPE_NOTIFICATION);

    /**
     * @return array
     */
    public function getMessages(): array
    {
        return $this->messages;
    }

    /**
     * @return array
     */
    public function getServiceResponse(): array
    {
        return $this->service_response;
    }

    /**
     * @param array $service_response
     */
    public function setServiceResponse(array $service_response): void
    {
        $this->service_response = $service_response;
    }

    /**
     * @param $message
     * @param array $vars
     * @return string|string[]
     */
    protected function replaceVars($message, $vars = []): array|string
    {
        //replace vars in messages
        //for each var in vars, replace the key with the value in the message
        foreach ($vars as $key => $value) {
            if(isset($vars[$key]))
                $message = str_replace('{{' . $key . '}}', $value, $message);
        }

        return $message;
    }


    abstract public function setupNotificationMessages(array $vars = []): void;
}