<?php

namespace JimsCustomerBooking;

use JimsCustomerBooking\Admin\BackendPages\CustomerBookingPage;
use JimsCustomerBooking\Admin\BackendPages\CustomerBookingSettingsPage;
use JimsCustomerBooking\Admin\BackendPages\EmailSubscriptionSettingsPage;
use JimsCustomerBooking\Admin\BackendPages\NativeFormSettingsPage;
use JimsCustomerBooking\Admin\BackendPages\FormCustomizeSettingsPage;
use JimsCustomerBooking\Database\Database;
use JimsCustomerBooking\Generators\CBURLGenerator;
use JimsCustomerBooking\Helpers\ColorHelper;
use JimsCustomerBooking\Helpers\OptionHelper;
use JimsCustomerBooking\Admin\BackendPages\CBLinkGeneratorPage;
use JimsCustomerBooking\Admin\BackendPages\SettingsPage;
use JimsCustomerBooking\Admin\BackendPages\ShortCodeGeneratorPage;
use JimsCustomerBooking\Helpers\StringHelper;
use JimsCustomerBooking\Integrations\JimsLeadsIntegration;
use JimsCustomerBooking\Middlewares\Http;
use JimsCustomerBooking\RestfulAPI\AuthenticationController;
use JimsCustomerBooking\RestfulAPI\BookingsStatisticsController;
use JimsCustomerBooking\RestfulAPI\CustomerBookingController;
use JimsCustomerBooking\RestfulAPI\CustomerBookingCustomizeController;
use JimsCustomerBooking\RestfulAPI\EmailSubscriptionController;
use JimsCustomerBooking\RestfulAPI\InputValidationController;
use JimsCustomerBooking\RestfulAPI\OptionController;
use JimsCustomerBooking\RestfulAPI\ScheduleController;
use JimsCustomerBooking\RestfulAPI\ServiceController;
use JimsCustomerBooking\Services\DivisionService;
use JimsCustomerBooking\Shortcodes\BookingFormShortCode;
use JimsCustomerBooking\Shortcodes\CBFormShortCode;
use JimsGroup\Utilities\Logger;

if (!class_exists('JimsCustomerBooking\Jims_Plugin')) {
    /**
     *
     */
    class Jims_Plugin
    {
        /**
         * @var string
         */
        private $mode = 'development';


        public static $version = '3.3.04';


        /**
         * --- PLEASE DO NOT CHANGE THIS ---
         * encryption key for the plugin
         * it should be a hexadecimal key, 136 characters long
         *
         */
        public const ENCRYPTION_KEY = 'def000008eb640d6634a6d422b06ecbbd8ed8bd0fc417c4831b7aa7bfb7c89a4caa3973a13288795670bbc0793fffa622cb5c99fa407069efb64a11a1b1d40716f3cd6c0';

        /**
         * key for the option in wordpress options table
         */
        const OPTION_NAME = 'wpcb';


        public const SECKEY = 'jims-wpcb-communication-key-v1';

        /**
         * --- PLEASE DO NOT CHANGE THIS ---
         * menu slug for admin
         */
        public const PREFIX = 'jims_wpcb';


        public const FMS_API_KEY = '3e8bce9e-be45-4499-b31a-23b6fb067aa7';

        public const FMS_TOKENS = [
            'secret' => 'yw86Dvcwwsm0vEpZ3oNRFrXkCNovNLKh',
            'fso_token' => 'Zm1zX3VzZXI6Q2I2MkFZaFRwOFdtYUJSMnBzUmpSNUxTTnNhRWY1cEw=',
            'fse_token' => 'amltc19qb2JzX21vYmlsZTpDNHFkOFl0OGVnWVVLMnRaZnlhNWtaUjVZR3JmNng0eQ=='
        ];

        public const FINDAJIM_TOKEN = '84bcb06b2d534989cf811f250b26dc10';


        public const FMS_API_MODES = [
            'production', 'uat', 'hf', 'staging', 'int', 'development', 'local' //local is for testing and available only for local environments
        ];

        /**
         * @var array
         */
        private array $rest_classes = [];


        private $registered = [];

        /**
         * @var null|JimsLeadsIntegration
         */
        private $leads = null;

        /**
         * main entry point
         */
        public function run()
        {
            add_action('plugins_loaded', [$this, 'activate']);
//            add_action('init', [$this, 'OverrideShortCodes'], 1);
            add_action('init', [$this, 'SetupShortcodes']);
            add_action('wp_enqueue_scripts', [$this, 'frontScripts']);
            add_action('admin_enqueue_scripts', [$this, 'adminScripts']);
            add_action('rest_api_init', array($this, 'registerRestAPI'));
            add_action(StringHelper::GetPrefixed('jims_logo'), [$this, 'setupJimsLogo']);
            add_action('admin_notices', [$this, 'showDashboardNotifications']);

            //filters
            add_filter('register_block_type_args', [$this, 'OverrideShortCodes'], 10, 2);

            function foo_register_gallery()
            {
                register_block_type('core/gallery', array(
                    'render_callback' => 'foo_gallery_render',
                ));
            }

            //Checks the theme and theme version and modifies settings to match
            $this->setupCompatibility();

            $this->registerBackendPages();

            $this->leads = JimsLeadsIntegration::getInstance();

            $this->setupMiddleWares();
        }

        /**
         * Adds frontend scripts
         * @return void
         */
        public function frontScripts()
        {
            wp_register_script(StringHelper::GetPrefixed('js'), plugins_url('/assets/dist/js/front.js', JIMS_CBP_FILE), [], $this->getVersion(), true);

            wp_register_style(StringHelper::GetPrefixed('final'), false);

            list($main_color, $main_color_dim) = $this->getFormColors();
            wp_add_inline_style(StringHelper::GetPrefixed('final'), \sprintf(":root { --nwpcb-main-color: %s; --nwpcb-main-color-dim: %s }", $main_color, $main_color_dim));

            wp_enqueue_style(StringHelper::GetPrefixed('style'), plugins_url('/assets/dist/css/front.css', JIMS_CBP_FILE), [
                StringHelper::GetPrefixed('final')
            ], $this->getVersion());


            OptionHelper::localizeFormVariables('js');
            wp_enqueue_script(StringHelper::GetPrefixed('js'));
        }

        /**
         * @return void
         */
        public function adminScripts()
        {
            wp_enqueue_script(StringHelper::GetPrefixed('html-extension'), plugins_url('/assets/dist/js/html-extension.js', JIMS_CBP_FILE), [], $this->getVersion());

            wp_register_script(StringHelper::GetPrefixed('admin-js'), plugins_url('/assets/dist/js/admin.js', JIMS_CBP_FILE), [], $this->getVersion(), true);
            OptionHelper::localizeFormVariables('admin-js');

            wp_enqueue_script(StringHelper::GetPrefixed('admin-js'));
            wp_enqueue_style(StringHelper::GetPrefixed('admin-style'), plugins_url('/assets/dist/css/admin.css', JIMS_CBP_FILE), [], $this->getVersion());

            //enqueue fontawesome if not theme is not the new jims theme
            if (strpos(strtolower(wp_get_theme()->Name), 'jims') === false || strpos(strtolower(wp_get_theme()->Name), 'enfold') !== false) {
                wp_register_style(StringHelper::GetPrefixed('fontawesome-solid'), plugins_url('/assets/dist/fonts/css/solid.css', JIMS_CBP_FILE), [], $this->getVersion());
                wp_enqueue_style(StringHelper::GetPrefixed('fontawesome-style'), plugins_url('/assets/dist/fonts/css/fontawesome.css', JIMS_CBP_FILE), [StringHelper::GetPrefixed('fontawesome-solid')], $this->getVersion());
            }
        }

        /**
         * @return array
         */
        public function registerBackendPages()
        {
            return $this->registered['backend_pages'] = [
                SettingsPage::class => new SettingsPage(),
                NativeFormSettingsPage::class => new NativeFormSettingsPage(),
                FormCustomizeSettingsPage::class => new FormCustomizeSettingsPage(),
                EmailSubscriptionSettingsPage::class => new EmailSubscriptionSettingsPage(),
                CustomerBookingPage::class => new CustomerBookingPage(),
//                CustomerBookingSettingsPage::class => new CustomerBookingSettingsPage(),
                ShortCodeGeneratorPage::class => new ShortCodeGeneratorPage(),
            ];
        }

        public function showDashboardNotifications()
        {
            if (!$this->isUserSubscribed()) {
                printf(
                    '<div class="notice notice-error is-dismissible"><p>%s <a href="%s">here</a></p></div>',
                    'WP CB form is <strong>LOCKED</strong>! To unlock please subscribe to our email service ',
                    admin_url('admin.php?page=wpcb_subscription_settings.php')
                );
            }

            if ($this->leads->getSiteStatus() === false) {
                printf(
                    '<div class="notice notice-error is-dismissible"><p>%s <a href="%s">%s</a> %s</p></div>',
                    'Your website appears to be actively blocking Jim\'s Group monitoring servers. This could potentially affect the health and error tracking of your CB form. Please ',
                    'mailto:infotech@jims.net',
                    'contact support',
                    'for more information.'
                );
            }
        }

        public function isUserSubscribed()
        {
            $options = OptionHelper::get(EmailSubscriptionSettingsPage::$option_name, []);
            return isset($options['email']) && strlen($options['email']) > 3 && str_contains($options['email'], '@') ?? false;
        }

        public function SetupShortcodes()
        {
            if($this->isUserSubscribed()) {
                return $this->registered['shortcodes'] = [
                    BookingFormShortCode::class => new BookingFormShortCode()
                ];
            }

            return $this->registered['shortcodes'] = [];
        }

        /**
         * @param $args
         * @param $name
         * @return mixed
         */
        public function OverrideShortCodes($args, $name): mixed
        {
//            register_block_type( 'core/shortcode', array(
//                'render_callback' => 'GutenbergBlockHelper::ShortCodeRender',
//            ) );

            if ($name === 'core/shortcode') {
                $args['render_callback'] = 'GutenbergBlockHelper::ShortCodeRender';
            }

            return $args;
        }

        /**
         * @return void
         */
        public function registerRestAPI(): void
        {
            $this->rest_classes = [
                InputValidationController::class => new InputValidationController(),
                OptionController::class => new OptionController(),
                ServiceController::class => new ServiceController(),
                AuthenticationController::class => new AuthenticationController(),
                CustomerBookingController::class => new CustomerBookingController(),
                BookingsStatisticsController::class => new BookingsStatisticsController(),
                CustomerBookingCustomizeController::class => new CustomerBookingCustomizeController(),
                EmailSubscriptionController::class => new EmailSubscriptionController(),
                ScheduleController::class => new ScheduleController()
            ];

            //register rest api controllers hook
            $this->rest_classes = apply_filters(self::PREFIX . '_rest_controller_register', $this->rest_classes);
        }

        /**
         * @return Http[]
         */
        protected function setupMiddleWares(): array
        {
            return $this->registered['middlewares'] = [
//                Http::class => new Http()
            ];
        }

        /**
         * @return Jims_Options
         */
        public static function getOptions(): Jims_Options
        {
            return OptionHelper::getEmbeddedFormOptions();
        }

        /**
         * @return void
         */
        public function activate(): void
        {
            $option_name = StringHelper::GetPrefixed('version', 'machine');
            $current_version = get_option($option_name, '0.0.0');

            if ($current_version != JIMS_CBP_VERSION) {
                update_option($option_name, JIMS_CBP_VERSION, true);
                Database::setupOrUpdateDatabase($current_version);

                //update website on leads.jims.net
                $res = $this->updateWebsiteToLeads();
                Logger::info( is_wp_error($res) ? $res->get_error_message() : $res );
            }
        }

        public function getVersion(): string|int
        {
            if ($this->mode === 'development') return time();
            else return self::$version;
        }

        public function setupCompatibility(): void
        {
            $theme = wp_get_theme();
            $theme_name = $theme->get('Name');
            $theme_version = $theme->get('Version');

            // check if enfold theme is active and get logo from theme options
            add_filter(StringHelper::getPrefixed('booking_form_logo_url'), function ($logo) use ($theme_name, $theme_version) {

                if (str_contains(strtolower($theme_name), 'enfold')) {
                    $options = get_option('avia_options_jims_enfold');
                    $logo = isset($options['avia'], $options['avia']['logo']) ? $options['avia']['logo'] : '';
                }

                return $logo;
            }, 99, 1);
        }

        /**
         * @param $name
         * @return mixed
         */
        public function getRegistered($name): array
        {
            return isset($this->registered[$name]) ? $this->registered[$name] : $this->registered;
        }

        public function setupJimsLogo(): void
        {
            $plugin_url = plugins_url('/assets/dist/img/jims.png', JIMS_CBP_FILE);
            printf('<img src="%s" alt="%s">', $plugin_url, "Jims Logo");
        }

        /**
         * @return array
         */
        public function getFormColors(): array
        {
            $main_color = OptionHelper::getValue(NativeFormSettingsPage::$option_name, 'bookingFormMainColor', '');
            if (empty($main_color)) {
                $main_color = '#0b75b4';
            }

            $main_color_dim = \sprintf('rgb(%s,%s,%s)', ...ColorHelper::darken($main_color, 10, false));
            return array($main_color, $main_color_dim);
        }

        public function updateWebsiteToLeads(): array|\WP_Error
        {
           return $this->leads->updateWebsite();
        }
    }
}